PyPI client
===========

```
Usage: pypi-client [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  auth-github  Log into GitHub
  search       Search python package by name
```